@@ -9,6 +9,7 @@ export * from './deaths.js';
 export * from './diagnoses.js';
 export * from './documents.js';
 export * from './encounters.js';
+export * from './facts.js';
 export * from './fhir.js';
 export * from './imaging.js';
 export * from './importable.js';
@@ -34,7 +35,6 @@ export * from './programRegistry.js';
 export * from './vaccines.js';
 export * from './settings.js';
 export * from './encounterHistory.js';
-export * from './font.js';
 export * from './webSocket.js';
 export * from './enumRegistry.js';
 export * from './materializedView.js';
