@@ -12,61 +12,64 @@ import {
   REGISTRATION_STATUSES,
   SUGGESTER_ENDPOINTS,
   SURVEY_TYPES,
-  TRANSLATABLE_REFERENCE_TYPES,
   VISIBILITY_STATUSES,
   OTHER_REFERENCE_TYPES,
+  REFERENCE_DATA_RELATION_TYPES,
   DEFAULT_LANGUAGE_CODE,
 } from '@tamanu/constants';
 import { v4 as uuidv4 } from 'uuid';
 import { customAlphabet } from 'nanoid';
 
-export const suggestions = express.Router();
-
-const defaultLimit = 25;
-
-const defaultMapper = ({ name, code, id }) => ({ name, code, id });
-
-const replaceDataLabelWithTranslation = (item) => {
-  if (item.dataValues.translated_name) {
-    item.setDataValue('name', item.dataValues.translated_name);
-  }
-  return item;
-};
-
+const DEFAULT_LIMIT = 25;
 const ENDPOINT_TO_DATA_TYPE = {
   // Special cases where the endpoint name doesn't match the dataType
   ['facilityLocationGroup']: OTHER_REFERENCE_TYPES.LOCATION_GROUP,
   ['bookableLocationGroup']: OTHER_REFERENCE_TYPES.LOCATION_GROUP,
   ['patientLabTestCategories']: REFERENCE_TYPES.LAB_TEST_CATEGORY,
   ['patientLabTestPanelTypes']: OTHER_REFERENCE_TYPES.LAB_TEST_PANEL,
-  ['invoiceProducts']: OTHER_REFERENCE_TYPES.INVOICE_PRODUCT,
+  ['invoiceProduct']: OTHER_REFERENCE_TYPES.INVOICE_PRODUCT,
 };
 const getDataType = (endpoint) => ENDPOINT_TO_DATA_TYPE[endpoint] || endpoint;
-const getTranslationPrefix = (dataType) => `${REFERENCE_DATA_TRANSLATION_PREFIX}.${dataType}.`;
+// The string_id for the translated_strings table is a concatenation of this prefix
+// and the id of the record so we need to construct it for the translation attribute
+const getTranslationPrefix = (endpoint) =>
+  `${REFERENCE_DATA_TRANSLATION_PREFIX}.${getDataType(endpoint)}.`;
 
-const getTranslationAttributes = (endpoint, modelName) => {
-  const dataType = getDataType(endpoint);
-  return {
-    include: [
-      [
-        Sequelize.literal(`(
-        SELECT "text" 
-        FROM "translated_strings" 
-        WHERE "language" = :language
-        AND "string_id" = '${getTranslationPrefix(dataType)}' || "${modelName}"."id"
-        LIMIT 1
-      )`),
-        'translated_name',
-      ],
-    ],
-  };
-};
+// Helper function to generate the translation subquery
+const getTranslationSubquery = (endpoint, modelName) => `(
+  SELECT "text"
+  FROM "translated_strings"
+  WHERE "language" = $language
+  AND "string_id" = '${getTranslationPrefix(endpoint)}' || "${modelName}"."id"
+  LIMIT 1
+)`;
+
+// Get the translation label for the record, otherwise the get the untranslated searchColumn
+const translationCoalesce = (endpoint, modelName, searchColumn) =>
+  `COALESCE(${getTranslationSubquery(endpoint, modelName)}, "${modelName}"."${searchColumn}")`;
+const translationCoalesceLiteral = (endpoint, modelName, searchColumn) =>
+  Sequelize.literal(translationCoalesce(endpoint, modelName, searchColumn));
+
+// Overwrite the default search column with translation if it exists
+const getTranslationAttributes = (endpoint, modelName, searchColumn = 'name') => ({
+  include: [[translationCoalesceLiteral(endpoint, modelName, searchColumn), searchColumn]],
+});
+
+export const suggestions = express.Router();
 
 function createSuggesterRoute(
   endpoint,
   modelName,
   whereBuilder,
-  { mapper, searchColumn, extraReplacementsBuilder, includeBuilder, orderBuilder },
+  {
+    mapper,
+    searchColumn,
+    extraReplacementsBuilder,
+    includeBuilder,
+    orderBuilder,
+    shouldSkipDefaultOrder,
+    queryOptions
+  },
 ) {
   suggestions.get(
     `/${endpoint}$`,
@@ -79,61 +82,53 @@ function createSuggesterRoute(
 
       const searchQuery = (query.q || '').trim().toLowerCase();
       const positionQuery = literal(
-        `POSITION(LOWER(:positionMatch) in LOWER(${`"${modelName}"."${searchColumn}"`})) > 1`,
+        `POSITION(LOWER($positionMatch) in LOWER(${translationCoalesce(endpoint, modelName, searchColumn)})) > 1`,
       );
-      const dataType = getDataType(endpoint);
-      const translationPrefix = getTranslationPrefix(dataType);
 
-      const isTranslatable = TRANSLATABLE_REFERENCE_TYPES.includes(dataType);
-      const hasTranslations = await models.TranslatedString.count({
-        where: {
-          language,
-          stringId: {
-            [Op.startsWith]: translationPrefix,
-          },
-        },
+      // We supply the searchQuery to both the whereBuilder and the bind so that we can
+      // either use the bind key in SQL or in the whereBuilder directly using sequelize
+      const where = whereBuilder({
+        search: `%${searchQuery}%`,
+        query,
+        req,
+        endpoint,
+        modelName,
+        searchColumn,
       });
 
-      const where =
-        isTranslatable && hasTranslations
-          ? Sequelize.literal(`EXISTS (
-            SELECT 1 
-            FROM translated_strings 
-            WHERE language = :language
-            AND string_id = '${translationPrefix}' || "${modelName}"."id"
-            AND text ILIKE :searchQuery
-          )`)
-          : whereBuilder(`%${searchQuery}%`, query, req);
-
       if (endpoint === 'location' && query.locationGroupId) {
         where.locationGroupId = query.locationGroupId;
       }
 
       const include = includeBuilder?.(req);
       const order = orderBuilder?.(req);
+      const skipDefaultOrder = shouldSkipDefaultOrder?.(req);
+      const defaultOrder = [
+        positionQuery,
+        [translationCoalesceLiteral(endpoint, modelName, searchColumn), 'ASC'],
+      ];
 
       const results = await model.findAll({
         where,
         include,
-        attributes: getTranslationAttributes(endpoint, modelName),
+        attributes: getTranslationAttributes(endpoint, modelName, searchColumn),
         order: [
+          // TODO: This is a hack to avoid ambiguous column references when we have includes
+          // need to either fix this or enforce custom orderBuilder
           ...(order ? [order] : []),
-          positionQuery,
-          [Sequelize.literal(`"${modelName}"."${searchColumn}"`), 'ASC'],
+          ...(skipDefaultOrder ? [] : defaultOrder),
         ],
-        replacements: {
+        bind: {
           positionMatch: searchQuery,
           language,
           searchQuery: `%${searchQuery}%`,
           ...extraReplacementsBuilder(query),
         },
-        limit: defaultLimit,
+        limit: DEFAULT_LIMIT,
+        ...queryOptions,
       });
-
-      const translatedData = results.map(replaceDataLabelWithTranslation);
-
       // Allow for async mapping functions (currently only used by location suggester)
-      res.send(await Promise.all(translatedData.map(mapper)));
+      res.send(await Promise.all(results.map(mapper)));
     }),
   );
 }
@@ -141,7 +136,7 @@ function createSuggesterRoute(
 // this exists so a control can look up the associated information of a given suggester endpoint
 // when it's already been given an id so that it's guaranteed to have the same structure as the
 // options endpoint
-function createSuggesterLookupRoute(endpoint, modelName, { mapper }) {
+function createSuggesterLookupRoute(endpoint, modelName, { mapper, searchColumn }) {
   suggestions.get(
     `/${endpoint}/:id`,
     asyncHandler(async (req, res) => {
@@ -154,19 +149,15 @@ function createSuggesterLookupRoute(endpoint, modelName, { mapper }) {
 
       const record = await models[modelName].findOne({
         where: { id: params.id },
-        attributes: getTranslationAttributes(endpoint, modelName),
-        replacements: {
+        bind: {
           language,
         },
+        attributes: getTranslationAttributes(endpoint, modelName, searchColumn),
       });
 
       if (!record) throw new NotFoundError();
 
-      req.checkPermission('read', record);
-
-      const translatedRecord = replaceDataLabelWithTranslation(record);
-
-      res.send(await mapper(translatedRecord));
+      res.send(await mapper(record));
     }),
   );
 }
@@ -185,23 +176,20 @@ function createAllRecordsRoute(
       const { language = DEFAULT_LANGUAGE_CODE } = query;
 
       const model = models[modelName];
-
-      const where = whereBuilder('%', query, req);
+      const where = whereBuilder({ search: '%', query, req, endpoint, modelName, searchColumn });
 
       const results = await model.findAll({
         where,
-        attributes: getTranslationAttributes(endpoint, modelName),
-        order: [[Sequelize.literal(searchColumn), 'ASC']],
-        replacements: {
+        order: [[translationCoalesceLiteral(endpoint, modelName, searchColumn), 'ASC']],
+        attributes: getTranslationAttributes(endpoint, modelName, searchColumn),
+        bind: {
           language,
+          searchQuery: '%',
           ...extraReplacementsBuilder(query),
         },
       });
-
-      const translatedResults = results.map(replaceDataLabelWithTranslation);
-
       // Allow for async mapping functions (currently only used by location suggester)
-      res.send(await Promise.all(translatedResults.map(mapper)));
+      res.send(await Promise.all(results.map(mapper)));
     }),
   );
 }
@@ -228,6 +216,24 @@ function createSuggesterCreateRoute(
   );
 }
 
+// Search against the translation if it exists, otherwise search against the searchColumn
+const getTranslationWhereLiteral = (endpoint, modelName, searchColumn) => {
+  return Sequelize.literal(
+    `${translationCoalesce(endpoint, modelName, searchColumn)} ILIKE $searchQuery`,
+  );
+};
+
+const DEFAULT_WHERE_BUILDER = ({ endpoint, modelName, searchColumn = 'name' }) => ({
+  [Op.or]: [getTranslationWhereLiteral(endpoint, modelName, searchColumn)],
+  ...VISIBILITY_CRITERIA,
+});
+
+const DEFAULT_MAPPER = ({ name, code, id }) => ({
+  name,
+  code,
+  id,
+});
+
 // Add a new suggester for a particular model at the given endpoint.
 // Records will be filtered based on the whereSql parameter. The user's search term
 // will be passed to the sql query as ":search" - see the existing suggestion
@@ -240,7 +246,7 @@ function createSuggester(
   allowCreatingNewSuggestion,
 ) {
   const options = {
-    mapper: defaultMapper,
+    mapper: DEFAULT_MAPPER,
     searchColumn: 'name',
     extraReplacementsBuilder: () => {},
     ...optionOverrides,
@@ -291,10 +297,9 @@ const referenceDataBodyBuilder = ({ type, name }) => {
 createSuggester(
   'multiReferenceData',
   'ReferenceData',
-  (search, { types }) => ({
+  ({ endpoint, modelName, query: { types } }) => ({
+    ...DEFAULT_WHERE_BUILDER({ endpoint, modelName }),
     type: { [Op.in]: types },
-    name: { [Op.iLike]: search },
-    ...VISIBILITY_CRITERIA,
   }),
   {
     includeBuilder: (req) => {
@@ -337,7 +342,7 @@ createSuggester(
       if (!types?.length) return;
 
       const caseStatement = types
-        .map((_, index) => `WHEN :type${index} THEN ${index + 1}`)
+        .map((_, index) => `WHEN $type${index} THEN ${index + 1}`)
         .join(' ');
 
       return [
@@ -358,6 +363,7 @@ createSuggester(
     creatingBodyBuilder: (req) =>
       referenceDataBodyBuilder({ type: req.body.type, name: req.body.name }),
     afterCreated: afterCreatedReferenceData,
+    shouldSkipDefaultOrder: () => true,
   },
   true,
 );
@@ -366,51 +372,79 @@ REFERENCE_TYPE_VALUES.forEach((typeName) => {
   createSuggester(
     typeName,
     'ReferenceData',
-    (search) => ({
-      name: { [Op.iLike]: search },
+    ({ endpoint, modelName }) => ({
+      ...DEFAULT_WHERE_BUILDER({ endpoint, modelName }),
       type: typeName,
-      ...VISIBILITY_CRITERIA,
     }),
     {
       includeBuilder: (req) => {
         const {
-          models: { ReferenceData },
+          models: { ReferenceData, ReferenceMedicationTemplate },
           query: { parentId, relationType = DEFAULT_HIERARCHY_TYPE },
         } = req;
-        if (!parentId) return undefined;
 
-        return {
-          model: ReferenceData,
-          as: 'parent',
-          required: true,
-          through: {
-            attributes: [],
-            where: {
-              referenceDataParentId: parentId,
-              type: relationType,
+        const result = [
+          parentId && {
+            model: ReferenceData,
+            as: 'parent',
+            required: true,
+            through: {
+              attributes: ['id'],
+              where: {
+                referenceDataParentId: parentId,
+                type: relationType,
+              },
             },
           },
-        };
+          typeName === REFERENCE_TYPES.DRUG && 'referenceDrug',
+          typeName === REFERENCE_TYPES.MEDICATION_SET && {
+            model: ReferenceData,
+            as: 'children',
+            where: VISIBILITY_CRITERIA,
+            through: {
+              attributes: [],
+              where: {
+                type: REFERENCE_DATA_RELATION_TYPES.MEDICATION,
+                deleted_at: null,
+              },
+            },
+            include: {
+              model: ReferenceMedicationTemplate,
+              as: 'medicationTemplate',
+              include: {
+                model: ReferenceData,
+                as: 'medication',
+                where: VISIBILITY_CRITERIA,
+              },
+            },
+          },
+        ].filter(Boolean);
+
+        return result.length > 0 ? result : null;
       },
+      queryOptions: typeName === REFERENCE_TYPES.MEDICATION_SET ? { subQuery: false } : {},
       creatingBodyBuilder: (req) =>
         referenceDataBodyBuilder({ type: typeName, name: req.body.name }),
       afterCreated: afterCreatedReferenceData,
+      mapper: (item) => item,
+      shouldSkipDefaultOrder: (req) =>
+        req.query.parentId || typeName === REFERENCE_TYPES.MEDICATION_SET,
     },
     true,
   );
 });
 
 createSuggester('labTestType', 'LabTestType', () => VISIBILITY_CRITERIA, {
-  mapper: ({ name, code, id, labTestCategoryId }) => ({ name, code, id, labTestCategoryId }),
+  mapper: ({ name, code, id, labTestCategoryId }) => ({
+    name,
+    code,
+    id,
+    labTestCategoryId,
+  }),
 });
 
-const DEFAULT_WHERE_BUILDER = (search) => ({
-  name: { [Op.iLike]: search },
-  ...VISIBILITY_CRITERIA,
-});
-
-const filterByFacilityWhereBuilder = (search, query) => {
-  const baseWhere = DEFAULT_WHERE_BUILDER(search);
+const filterByFacilityWhereBuilder = ({ query, modelName, endpoint }) => {
+  const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
   // Parameters are passed as strings, so we need to check for 'true'
   const shouldFilterByFacility =
     query.filterByFacility === 'true' || query.filterByFacility === true;
@@ -431,9 +465,9 @@ const createNameSuggester = (
   options,
 ) =>
   createSuggester(endpoint, modelName, whereBuilderFn, {
-    mapper: ({ id, name }) => ({
-      id,
+    mapper: ({ name, id }) => ({
       name,
+      id,
     }),
     ...options,
   });
@@ -446,8 +480,8 @@ createSuggester(
   'location',
   'Location',
   // Allow filtering by parent location group
-  (search, query) => {
-    const baseWhere = filterByFacilityWhereBuilder(search, query);
+  ({ endpoint, modelName, query }) => {
+    const baseWhere = filterByFacilityWhereBuilder({ endpoint, modelName, query });
 
     const { ...filters } = query;
     delete filters.q;
@@ -470,7 +504,7 @@ createSuggester(
       const lg = await location.getLocationGroup();
       const locationGroup = lg && { name: lg.name, code: lg.code, id: lg.id };
       return {
-        name,
+        name: name,
         code,
         maxOccupancy,
         id,
@@ -485,17 +519,25 @@ createSuggester(
 createNameSuggester('locationGroup', 'LocationGroup', filterByFacilityWhereBuilder);
 
 // Location groups filtered by facility. Used in the survey form autocomplete
-createNameSuggester('facilityLocationGroup', 'LocationGroup', (search, query) =>
-  filterByFacilityWhereBuilder(search, { ...query, filterByFacility: true }),
+createNameSuggester('facilityLocationGroup', 'LocationGroup', ({ endpoint, modelName, query }) =>
+  filterByFacilityWhereBuilder({
+    endpoint,
+    modelName,
+    query: { ...query, filterByFacility: true },
+  }),
 );
 
 // Location groups filtered by isBookable. Used in location bookings view
-createNameSuggester('bookableLocationGroup', 'LocationGroup', (search, query) => ({
-  ...filterByFacilityWhereBuilder(search, { ...query, filterByFacility: true }),
+createNameSuggester('bookableLocationGroup', 'LocationGroup', ({ endpoint, modelName, query }) => ({
+  ...filterByFacilityWhereBuilder({
+    endpoint,
+    modelName,
+    query: { ...query, filterByFacility: true },
+  }),
   isBookable: true,
 }));
 
-createNameSuggester('survey', 'Survey', (search, { programId }) => ({
+createNameSuggester('survey', 'Survey', ({ search, query: { programId } }) => ({
   name: { [Op.iLike]: search },
   ...(programId ? { programId } : programId),
   surveyType: {
@@ -504,12 +546,11 @@ createNameSuggester('survey', 'Survey', (search, { programId }) => ({
 }));
 
 createSuggester(
-  'invoiceProducts',
+  'invoiceProduct',
   'InvoiceProduct',
-  (search) => ({
-    name: { [Op.iLike]: search },
+  ({ endpoint, modelName }) => ({
+    ...DEFAULT_WHERE_BUILDER({ endpoint, modelName }),
     '$referenceData.type$': REFERENCE_TYPES.ADDITIONAL_INVOICE_PRODUCT,
-    ...VISIBILITY_CRITERIA,
   }),
   {
     mapper: (product) => {
@@ -531,7 +572,7 @@ createSuggester(
 createSuggester(
   'practitioner',
   'User',
-  (search) => ({
+  ({ search }) => ({
     displayName: { [Op.iLike]: search },
     ...VISIBILITY_CRITERIA,
   }),
@@ -556,7 +597,7 @@ const trimAndConcat = (col1, col2) =>
 createSuggester(
   'patient',
   'Patient',
-  (search) => ({
+  ({ search }) => ({
     [Op.or]: [
       Sequelize.where(trimAndConcat('first_name', 'last_name'), { [Op.iLike]: search }),
       Sequelize.where(trimAndConcat('last_name', 'first_name'), { [Op.iLike]: search }),
@@ -583,8 +624,8 @@ createSuggester(
   },
 );
 
-createSuggester('nonSensitiveLabTestCategory', 'ReferenceData', (search) => {
-  const baseWhere = DEFAULT_WHERE_BUILDER(search);
+createSuggester('nonSensitiveLabTestCategory', 'ReferenceData', ({ endpoint, modelName }) => {
+  const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
   return {
     ...baseWhere,
     type: REFERENCE_TYPES.LAB_TEST_CATEGORY,
@@ -600,8 +641,8 @@ createSuggester('nonSensitiveLabTestCategory', 'ReferenceData', (search) => {
   };
 });
 
-createSuggester('sensitiveLabTestCategory', 'ReferenceData', (search) => {
-  const baseWhere = DEFAULT_WHERE_BUILDER(search);
+createSuggester('sensitiveLabTestCategory', 'ReferenceData', ({ endpoint, modelName }) => {
+  const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
   return {
     ...baseWhere,
     type: REFERENCE_TYPES.LAB_TEST_CATEGORY,
@@ -621,8 +662,8 @@ createSuggester('sensitiveLabTestCategory', 'ReferenceData', (search) => {
 createSuggester(
   'patientLabTestCategories',
   'ReferenceData',
-  (search, query, req) => {
-    const baseWhere = DEFAULT_WHERE_BUILDER(search);
+  ({ endpoint, modelName, query, req }) => {
+    const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
 
     if (!query.patientId) {
       return { ...baseWhere, type: REFERENCE_TYPES.LAB_TEST_CATEGORY };
@@ -635,8 +676,8 @@ createSuggester(
           FROM lab_requests
           INNER JOIN
             encounters ON encounters.id = lab_requests.encounter_id
-          WHERE lab_requests.status = :lab_request_status
-            AND encounters.patient_id = :patient_id
+          WHERE lab_requests.status = $lab_request_status
+            AND encounters.patient_id = $patient_id
             AND encounters.deleted_at is null
             AND lab_requests.deleted_at is null
         )`,
@@ -654,8 +695,8 @@ createSuggester(
             ON (lab_requests.id = lab_tests.lab_request_id)
           INNER JOIN lab_test_types
             ON (lab_test_types.id = lab_tests.lab_test_type_id)
-          WHERE lab_requests.status = :lab_request_status
-            AND encounters.patient_id = :patient_id
+          WHERE lab_requests.status = $lab_request_status
+            AND encounters.patient_id = $patient_id
             AND encounters.deleted_at is null
             AND lab_requests.deleted_at is null
             AND lab_test_types.is_sensitive IS FALSE
@@ -681,8 +722,8 @@ createSuggester(
 createSuggester(
   'patientLabTestPanelTypes',
   'LabTestPanel',
-  (search, query) => {
-    const baseWhere = DEFAULT_WHERE_BUILDER(search);
+  ({ endpoint, modelName, query }) => {
+    const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
 
     if (!query.patientId) {
       return baseWhere;
@@ -703,8 +744,8 @@ createSuggester(
             lab_requests ON lab_requests.id = lab_tests.lab_request_id
           INNER JOIN
             encounters ON encounters.id = lab_requests.encounter_id
-          WHERE lab_requests.status = :lab_request_status
-            AND encounters.patient_id = :patient_id
+          WHERE lab_requests.status = $lab_request_status
+            AND encounters.patient_id = $patient_id
             AND encounters.deleted_at is null
             AND lab_requests.deleted_at is null
         )`,
@@ -723,8 +764,8 @@ createSuggester(
 createNameSuggester(
   'programRegistryClinicalStatus',
   'ProgramRegistryClinicalStatus',
-  (search, { programRegistryId }) => ({
-    ...DEFAULT_WHERE_BUILDER(search),
+  ({ endpoint, modelName, query: { programRegistryId } }) => ({
+    ...DEFAULT_WHERE_BUILDER({ endpoint, modelName }),
     ...(programRegistryId ? { programRegistryId } : {}),
   }),
 );
@@ -732,8 +773,8 @@ createNameSuggester(
 createSuggester(
   'programRegistry',
   'ProgramRegistry',
-  (search, query) => {
-    const baseWhere = DEFAULT_WHERE_BUILDER(search);
+  ({ endpoint, modelName, query }) => {
+    const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
     if (!query.patientId) {
       return baseWhere;
     }
@@ -749,7 +790,7 @@ createSuggester(
           INNER JOIN patient_program_registrations ppr
           ON ppr.program_registry_id = pr.id
           WHERE
-            ppr.patient_id = :patient_id
+            ppr.patient_id = $patient_id
           AND
             ppr.registration_status != '${REGISTRATION_STATUSES.RECORDED_IN_ERROR}'
         )`,
@@ -767,8 +808,8 @@ createSuggester(
 createNameSuggester(
   'programRegistryClinicalStatus',
   'ProgramRegistryClinicalStatus',
-  (search, { programRegistryId }) => ({
-    ...DEFAULT_WHERE_BUILDER(search),
+  ({ endpoint, modelName, query: { programRegistryId } }) => ({
+    ...DEFAULT_WHERE_BUILDER({ endpoint, modelName }),
     ...(programRegistryId ? { programRegistryId } : {}),
   }),
 );
@@ -776,8 +817,8 @@ createNameSuggester(
 createNameSuggester(
   'programRegistryCondition',
   'ProgramRegistryCondition',
-  (search, { programRegistryId }) => ({
-    ...DEFAULT_WHERE_BUILDER(search),
+  ({ endpoint, modelName, query: { programRegistryId } }) => ({
+    ...DEFAULT_WHERE_BUILDER({ endpoint, modelName }),
     ...(programRegistryId ? { programRegistryId } : {}),
   }),
 );
@@ -785,8 +826,8 @@ createNameSuggester(
 createNameSuggester(
   'programRegistry',
   'ProgramRegistry',
-  (search, query) => {
-    const baseWhere = DEFAULT_WHERE_BUILDER(search);
+  ({ endpoint, modelName, query }) => {
+    const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
     if (!query.patientId) {
       return baseWhere;
     }
@@ -802,7 +843,7 @@ createNameSuggester(
           INNER JOIN patient_program_registrations ppr
           ON ppr.program_registry_id = pr.id
           WHERE
-            ppr.patient_id = :patient_id
+            ppr.patient_id = $patient_id
           AND
             ppr.registration_status = '${REGISTRATION_STATUSES.ACTIVE}'
         )`,
@@ -820,8 +861,8 @@ createNameSuggester(
 // TODO: Use generic LabTest permissions for this suggester
 createNameSuggester('labTestPanel', 'LabTestPanel');
 
-createNameSuggester('template', 'Template', (search, query) => {
-  const baseWhere = DEFAULT_WHERE_BUILDER(search);
+createNameSuggester('template', 'Template', ({ endpoint, modelName, query }) => {
+  const baseWhere = DEFAULT_WHERE_BUILDER({ endpoint, modelName });
   const { type } = query;
 
   if (!type) {
